@@ -28,10 +28,9 @@ log = get_logger()
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
 @pass_context
 def jobs(ctx, is_mine, user_name, status, is_page, num, output, is_raw):
-    session = ctx.obj.session
     svc = ctx.obj.service
     if is_mine:
-        user_name = session.current_user['preferred_username']
+        user_name = svc.current_user['email']
 
     try:
         jobs = svc.get_jobs(user_name, status, num)
