@@ -69,7 +69,10 @@ def run(
         profile = profile or manifest.get('profile')
         params = manifest.get('params', {})
     try:
-        override_params = {p.split("=")[0].strip(): p.split("=")[1].strip() for p in parameters}
+        override_params = {}
+        for p in parameters:
+            lst = p.split("=", 1)
+            override_params[lst[0]] = lst[1].strip()
     except Exception:
         abort("Override parameters are badly formed. Expected '-p k1=v1 -p k2=v2'")
 
